@@ -394,6 +394,10 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
     // adapt icon size to dpi
     double dpi=QGuiApplication::primaryScreen()->logicalDotsPerInch();
     double scale=dpi/96;
+	int systemdpi = qRound(QGuiApplication::primaryScreen()->physicalDotsPerInch()); // main screen dpi
+	if (systemdpi < 10 || dpi > 1000)
+		systemdpi = 96;
+	QString labelSystemdpi = tr("Screen Resolution (System: %1 dpi):").arg(systemdpi);
 
 	setModal(true);
 	ui.setupUi(this);
@@ -418,7 +422,7 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 	ui.checkBoxUseQSaveWrite->setVisible(false);
 #endif
 
-    ui.checkBoxShowCommentedElementsInStructure->setVisible(false); // hide non-functional option, maybe it can be fixed in future
+    //ui.checkBoxShowCommentedElementsInStructure->setVisible(false); // hide non-functional option, maybe it can be fixed in future
 
     ui.contentsWidget->setIconSize(QSize(qRound(32*scale), qRound(32*scale)));
 	//ui.contentsWidget->setViewMode(QListView::ListMode);
@@ -580,6 +584,7 @@ ConfigDialog::ConfigDialog(QWidget *parent): QDialog(parent,Qt::Dialog|Qt::Windo
 	ui.comboBoxPreviewMode->removeItem(l - 1);
 	// maybe add some possibility to disable some preview modes in poppler mode
 #endif
+	ui.labelScreenResolution->setText(labelSystemdpi);
 
 	// set-up GUI scaling
 	connect(ui.tbRevertIcon, SIGNAL(clicked()), this, SLOT(revertClicked()));
@@ -1149,7 +1154,7 @@ void ConfigDialog::importDictionary()
 
 void ConfigDialog::updateCheckNow()
 {
-	UpdateChecker::instance()->check(false);
+	UpdateChecker::instance()->check(false, ui.comboBoxUpdateLevel->currentIndex());
 }
 
 void ConfigDialog::refreshLastUpdateTime()
