@@ -167,9 +167,9 @@ public:
 
 	Q_INVOKABLE bool containsPackage(const QString &name);
 	Q_INVOKABLE QStringList containedPackages();
-	Q_INVOKABLE QSet<QString> usedPackages();
-    bool updateCompletionFiles(const bool forceUpdate,const bool forceLabelUpdate = false,const bool delayUpdate = false, const bool dontPatch = false );
-	const QSet<QString> &getCWLFiles() const;
+    Q_INVOKABLE QSet<QString> usedPackages();
+    bool updateCompletionFiles(const bool forceUpdate,const bool forceLabelUpdate = false,const bool delayUpdate = false);
+    const QSet<QString> &getCWLFiles() const;
 
 	Q_INVOKABLE QString spellingDictName() const
 	{
