@@ -1,6 +1,7 @@
 #include "latexpackage.h"
 #include "latexcompleter_config.h"
 #include "latexparser/latexparser.h"
+#include "tablemanipulation.h"
 
 
 CommandDescription extractCommandDef(QString line, QString definition);
@@ -62,8 +63,13 @@ void LatexPackage::unite(LatexPackage &add, bool forCompletion)
 	}
 	optionCommands.unite(add.optionCommands);
 	environmentAliases.unite(add.environmentAliases);
-	specialTreatmentCommands.unite(add.specialTreatmentCommands);
-	specialDefCommands.unite(add.specialDefCommands);
+#if (QT_VERSION<QT_VERSION_CHECK(5,15,0))
+    specialTreatmentCommands.unite(add.specialTreatmentCommands);
+    specialDefCommands.unite(add.specialDefCommands);
+#else
+    specialTreatmentCommands.insert(add.specialTreatmentCommands);
+    specialDefCommands.insert(add.specialDefCommands);
+#endif
 	commandDescriptions.unite(add.commandDescriptions); // overloaded unit, which does not overwrite well defined CDs with poorly defined ones
 
 	//possibleCommands.unite(add.possibleCommands);
@@ -90,7 +96,9 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 	if (tagsfile.exists() && tagsfile.open(QFile::ReadOnly)) {
 		QString line;
 		QTextStream stream(&tagsfile);
-		stream.setCodec("UTF-8");
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+        stream.setCodec("UTF-8");
+#endif
 		QRegExp rxCom("^(\\\\\\w+\\*?)(\\[.+\\])*\\{(.*)\\}");  // expression for \cmd[opt]{arg} (cmd may be starred, [opt] can appear arbitrary often)
 		QRegExp rxCom2("^(\\\\\\w+\\*?)\\[(.+)\\]");            // expression for \cmd[opt]      (cmd may be starred)
 		QRegExp rxCom3("^(\\\\\\w+\\*?)");                      // expression for \cmd           (cmd may be starred)
@@ -100,6 +108,7 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 		QStringList specialTreatment;
 		specialTreatment << "color";
 		QString keyvals;
+        package.containsOptionalSections=false;
 		while (!stream.atEnd()) {
 			line = stream.readLine().trimmed();
 			if (line.startsWith("#endif")) {
@@ -108,6 +117,7 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 				continue;
 			}
 			if (line.startsWith("#ifOption:")) {
+                package.containsOptionalSections=true;
 				QString condition = line.mid(10);
 				skipSection = !(conditions.contains(condition) || conditions.contains(condition + "=true"));
 				continue;
@@ -281,6 +291,12 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 					}
 					valid.remove('i');
 				}
+                if (valid.contains('I')) { // include like command
+                    if (res > -1) {
+                        package.possibleCommands["%import"] << rxCom.cap(1);
+                    }
+                    valid.remove('I');
+                }
 				if (valid.contains('l')) { // label command
 					if (res > -1) {
 						package.possibleCommands["%label"] << rxCom.cap(1);
@@ -290,6 +306,18 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 				if (valid.contains('r')) { // ref command
 					if (res > -1) {
 						package.possibleCommands["%ref"] << rxCom.cap(1);
+
+                        QRegularExpression re{"{.*?}"};
+                        QRegularExpressionMatchIterator it = re.globalMatch(line);
+                        QRegularExpressionMatch match;
+                        for(int i=0;i<cd.argTypes.size();++i){
+                            match = it.next();
+                            if(cd.argTypes[i]==Token::labelRef)
+                                break;
+                        }
+                        if(match.hasMatch()){
+                            line.replace(match.capturedStart(),match.capturedLength(),"{@l}");
+                        }
 					}
 					valid.remove('r');
 				}
@@ -375,52 +403,24 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 					valid.remove('s');
 				}
 				if (valid.contains('c')) { // cite command
-					if (res > -1) {
-						package.possibleCommands["%cite"] << rxCom.cap(1);
-						// replace argument (possibly keylist) with @
-						int p = rxCom.pos(3);
-						int l = rxCom.cap(3).length();
-						if (p >= 0) {
-							line.replace(p, l, "@");
-						}
-					}
+                    // replace 'c' to 'C' to maintain cwl compatibility
 					valid.remove('c');
+                    valid.append('C');
 				}
 				if (valid.contains('C')) { // cite command
 					if (res > -1) {
-						if (!line.contains("%")) {
-							int start = 0;
-							if (line.startsWith("\\begin")) {
-								start = line.indexOf("}") + 1;
-							}
-							//add placeholders to brackets like () to (%<..%>)
-							const QString brackets = "{}[]()<>";
-							int lastOpen = -1, openType = -1;
-							for (int i = start; i < line.size(); i++) {
-								int index = brackets.indexOf(line[i]);
-								if (index >= 0) {
-									if (index % 2 == 0) {
-										lastOpen = i;
-										openType = index / 2;
-									} else {
-										if (lastOpen == -1 || openType != index / 2)
-											continue;
-										if (lastOpen == i - 1)
-											continue;
-										line.insert(lastOpen + 1, "%<");
-										i += 2;
-										line.insert(i, "%>");
-										lastOpen = -1;
-										i += 2;
-									}
-								}
-							}
-						}
-						package.possibleCommands["%citeExtended"] << line.simplified();
-						if (!line.startsWith("\\begin")) // HANDLE begin extra
-							package.possibleCommands["%citeExtendedCommand"] << rxCom.cap(1);
-						line.replace("%<bibid%>", "@");
-						//hideFromCompletion=true;
+                        QRegularExpression re{"{.*?}"};
+                        QRegularExpressionMatchIterator it = re.globalMatch(line);
+                        QRegularExpressionMatch match;
+                        for(int i=0;i<cd.argTypes.size();++i){
+                            match = it.next();
+                            if(cd.argTypes[i]==Token::bibItem)
+                                break;
+                        }
+                        package.possibleCommands["%cite"] << rxCom.cap(1);
+                        if (!line.startsWith("\\begin")) // HANDLE begin extra
+                            package.possibleCommands["%citeExtendedCommand"] << rxCom.cap(1);
+                        line.replace(match.capturedStart(),match.capturedLength(),"{@}");
 					}
 					valid.remove('C');
 				}
@@ -533,8 +533,15 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 						if (rxCom.cap(1) == "\\begin") {
 							QString envName = rxCom.cap(3);
 							if (!envName.isEmpty()) {
-								foreach (const QString &elem, env)
+                                foreach (const QString &elem, env){
 									package.environmentAliases.insert(rxCom.cap(3), elem);
+                                    if(elem=="tabular"){
+                                        LatexTables::tabularNames.insert(envName);
+                                    }
+                                    if(elem=="array"){
+                                        LatexTables::mathTables.insert(envName);
+                                    }
+                                }
 							}
 						}
 					}
@@ -543,7 +550,7 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 				if (hideFromCompletion)
 					continue; // command for spell checking only (auto parser)
 				// remove special option classification e.g. %l
-				line.remove(QRegExp("%[a-zA-Z]+")); // not n
+                line.remove(QRegularExpression("%[a-zA-Z]+")); // not n
 				if (!line.contains("%")) {
 					//add placeholders to brackets like () to (%<..%>)
 					const QString brackets = "{}[]()<>";
@@ -559,7 +566,7 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 									continue;
 								if (i - lastOpen < 2) // ignore empty arguments, feature request 888
 									continue;
-								if (i - lastOpen == 2 && line.mid(lastOpen + 1, 1) == "@") //ignore single @ (to be replaced with bibid in completer)
+                                if (line.mid(lastOpen + 1, 1) == "@" && line.mid(lastOpen + 2, 1) != "@") //ignore single @ (to be replaced with bibid in completer)
 									continue;
 								line.insert(lastOpen + 1, "%<");
 								i += 2;
@@ -584,11 +591,12 @@ LatexPackage loadCwlFile(const QString fileName, LatexCompleterConfig *config, Q
 					}
 				}
 
-				if (!words.contains(line)) {
-					CodeSnippet cs = CodeSnippet(line);
+                CodeSnippet cs = CodeSnippet(line);
+                uint hash = qHash(line);
+                CodeSnippetList::iterator it = std::lower_bound(words.begin(), words.end(), cs);
+                if (it == words.end() || it->index!=hash) {
                     CodeSnippetList::iterator it = std::lower_bound(words.begin(), words.end(), cs);
 					it = words.insert(it, cs);
-					uint hash = qHash(line);
 					int len = line.length();
 					it->index = hash;
 					it->snippetLength = len;
@@ -663,6 +671,7 @@ Token::TokenType tokenTypeFromCwlArg(QString arg, QString definition)
 	if (arg == "command" || arg == "cmd") return Token::def;
 	if (arg == "def" || arg == "definition" || arg == "begdef" || arg == "enddef") return Token::definition; // actual definition: \newcommand def defArgNumber definition
 	if (arg == "args") return Token::defArgNumber;
+    if (arg == "xargs") return Token::defXparseArg;
 	if (arg == "citekey") return Token::newBibItem;
 	if (arg == "default") return Token::optionalArgDefinition;
 	if (arg == "newlength") return Token::defWidth;
