@@ -237,11 +237,27 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                 continue;
             Token tk2 = tl.at(i + 1);
             Token tk3 = tl.at(i + 2);
-            if (tk2.type == Token::openBrace && tk3.type == Token::word) {
-                QString env = line.mid(tk3.start, tk3.length);
+            // search for closing brace (#2528)
+            Token tk_closing;
+            bool closingFound=false;
+            for(int j=i+3;j<tl.length();++j){
+                tk_closing=tl.at(j);
+                if(tk_closing.type == Token::closeBrace){
+                    closingFound=true;
+                    break;
+                }
+            }
+            if (tk2.type == Token::openBrace && closingFound) {
+                QString env = line.mid(tk3.start, tk_closing.start-tk3.start);
                 if (lp.possibleCommands["%verbatimEnv"].contains(env)) { // incomplete check if closing corresponds to open !
-                    verbatimMode = false;
-                    stack.pop();
+                    Token verbatimStart=stack.top();
+                    // second option, env in optionalCommandName
+                    if(verbatimStart.optionalCommandName.isEmpty() || verbatimStart.optionalCommandName==env){
+                        verbatimMode = false;
+                        stack.pop();
+                    }else{
+                        continue;
+                    }
                 } else
                     continue;
             } else
@@ -519,6 +535,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                                         tk3.dlh = dlh;
                                         tk3.level = level - 1;
                                         tk3.type = Token::verbatim;
+                                        tk3.optionalCommandName=env; // store verbatim env name (fix #2386, \end{diffVerbatim} was falsely used to close verbatim)
                                         stack.push(tk3);
                                     }
                                 } else { // only care for further arguments if not in verbatim mode (see minted)
@@ -556,7 +573,7 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                     lexed.append(tk);
                 }
                 if (!commandStack.isEmpty() && commandStack.top().level == level) {
-                    CommandDescription &cd = commandStack.top();
+                    CommandDescription cd = commandStack.top();
                     if (cd.args <= 0 && cd.bracketArgs <= 0) {
                         // all args handled, stop handling this command
                         commandStack.pop();
@@ -566,6 +583,8 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                             tk3.dlh = dlh;
                             tk3.level = level - 1;
                             tk3.type = Token::verbatim;
+                            QString env=cd.optionalCommandName.mid(7,cd.optionalCommandName.length()-8); // dirty solution, does not use tokens as it should
+                            tk3.optionalCommandName=env;
                             stack.push(tk3);
                         }
                     }
@@ -643,6 +662,27 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
                             }
                         }
                     }
+                    // special treatment for numbers after word (join them to word, see https://github.com/texstudio-org/texstudio/issues/2306 )
+                    if (tk.type == Token::number) {
+                        if(lastComma==(lexed.length()-2)){
+                            if((lexed[lastComma+1].start+lexed[lastComma+1].length==tk.start)&&lexed[lastComma+1].type==Token::word){
+                                lexed[lastComma+1].length+=tk.length;
+                                continue;
+                            }
+                        }
+                    }
+                    // special treatment for $ as mathstart
+                    if (line.mid(tk.start, 1) == "$") {
+                        tk.type = Token::command;
+                        if(i+1<tl.length()){
+                            if(line.mid(tk.start,2)=="$$"){
+                                i=i+1;
+                                tk.length=2;
+                            }
+                        }
+                        lexed << tk;
+                        continue;
+                    }
                     // add cmd/key as optionalCommandName
                     QString cmd=lexed[lastComma].optionalCommandName;
                     QString key=line.mid(lexed[lastComma].start, lexed[lastComma].length);
@@ -672,14 +712,6 @@ bool latexDetermineContexts2(QDocumentLineHandle *dlh, TokenStack &stack, Comman
         }
         if (tk.type == Token::symbol) {
             // special treatment for $ as mathstart
-            if (line.mid(tk.start, 2) == "$$") {
-                tk.type = Token::command;
-                tk.level = level;
-                tk.length=2;
-                lexed << tk;
-                i++;
-                continue;
-            }
             if (line.mid(tk.start, 1) == "$") {
                 tk.type = Token::command;
                 tk.level = level;
