@@ -1,5 +1,5 @@
-#ifndef LATEXTOKENS_H
-#define LATEXTOKENS_H
+#ifndef Header_Latex_Tokens
+#define Header_Latex_Tokens
 
 #include "mostQtHeaders.h"
 
@@ -16,7 +16,7 @@ class QDocument;
 class EnumsTokenType
 {
 	Q_GADGET
-	Q_ENUMS(TokenType)
+    Q_ENUMS(TokenType)
 
 public:
 	enum TokenType {
@@ -32,7 +32,7 @@ public:
 		verbatim, symbol, punctuation, number, generalArg,
 		defArgNumber, optionalArgDefinition, definition, defWidth, labelRefList,
         formula, specialArg, newTheorem, newBibItem, overlay,
-		overlayRegion, _end = 255
+        overlayRegion, defXparseArg, _end = 255
 	};
 };
 
@@ -79,6 +79,7 @@ public:
 	TokenType type;
 	/// subtype is used to determine the type of argument
 	TokenType subtype;
+    bool ignoreSpelling;
 	int argLevel; ///< number of argument (>0) or option (<0, =-numberOfOption)
 	static const QHash<TokenType, int> leftDelimWidth;  ///< width of the left delimiter in the token (if applicable)
 	static const QHash<TokenType, int> rightDelimWidth;  ///< width of the right delimiter in the token (if applicable)
