@@ -173,7 +173,7 @@ bool handleCommandLineOnly(const QStringList &cmdLine) {
 							<< "  --pdf-viewer-only         run as a standalone pdf viewer without an editor\n"
 							<< "  --page PAGENUM            display a certain page in the pdf viewer\n"
                             << "  --no-session              do not load/save the session at startup/close\n"
-                            << "  --texpath PATH            force resetting command defaults with PATH as first search path"
+                            << "  --texpath PATH            force resetting command defaults with PATH as first search path\n"
                             << "  --version                 show version number\n"
 #ifdef DEBUG_LOGGER
 							<< "  --debug-logfile pathname  write debug messages to pathname\n"
