@@ -61,8 +61,15 @@ class PDFAnnotation;
 class PDFAnnotationTableView;
 class MessageFrame;
 
+class PDFDraggableTool : public QLabel
+{
+public:
+	PDFDraggableTool(QWidget* parent): QLabel(parent) {}
+	virtual void reshape() = 0;
+	void drawCircleGradient(QPainter& painter, const QRect& outline, QColor color, int padding);
+};
 
-class PDFMagnifier : public QLabel
+class PDFMagnifier : public PDFDraggableTool
 {
 	Q_OBJECT
 
@@ -97,6 +104,17 @@ private:
 	int imagePage;
 };
 
+class PDFLaserPointer : public PDFDraggableTool {
+	Q_OBJECT
+
+public:
+	PDFLaserPointer(QWidget *parent);
+	void reshape();
+protected:
+	virtual void paintEvent(QPaintEvent *event);
+
+};
+
 #ifdef PHONON
 #include <phonon/VideoPlayer>
 
@@ -149,7 +167,7 @@ public:
 	void saveState(); // used when toggling full screen mode
 	void restoreState();
 	void setResolution(int res);
-	void resetMagnifier();
+	void resetDraggableTools();
 	Q_INVOKABLE int normalizedPageIndex(int pageIndex);
 	Q_INVOKABLE void goToPageDirect(int pageIndex, bool sync);
     Q_INVOKABLE void setHighlightPath(const int pageIndex, const QPainterPath &path, const bool dontRemove=false);
@@ -160,11 +178,14 @@ public:
     Q_INVOKABLE void reloadPage(bool sync = true);
 	void updateStatusBar();
 	void setGridSize(int gx, int gy, bool setAsDefault = false);
+	void setPageOffset(int offset, bool setAsDefault = false, bool refresh = false);
+	void setPageOffsetClick(const QPoint &p);
 	Q_INVOKABLE int visiblePages() const;
 	Q_INVOKABLE int pseudoNumPages() const;
 	Q_INVOKABLE int realNumPages() const;
 	Q_INVOKABLE int pageStep();
-	Q_INVOKABLE int gridCols() const;
+    Q_INVOKABLE int gridCols(bool fromConfig=false) const;
+    Q_INVOKABLE int gridRows(bool fromConfig=false) const;
 	Q_INVOKABLE int gridRowHeight() const;
 	Q_INVOKABLE int gridBorder() const;
 	Q_INVOKABLE PDFDocument *getPDFDocument();
@@ -223,6 +244,7 @@ public slots:
 	void fitWindow(bool checked = true);
 	void setTool(int tool);
 	void syncWindowClick(const QPoint &p, bool activate);
+	void getPosFromClick(const QPoint &p);
 	void syncCurrentPage(bool activate);
 	void fixedScale(qreal scale = 1.0);
 	void setImage(QPixmap img, int pageNr);
@@ -264,6 +286,8 @@ private:
 	void updateCursor(const QPoint &pos);
 	QRect mapPopplerRectToWidget(QRectF rect, const QSizeF &pageSize) const;
 	void useMagnifier(const QMouseEvent *inEvent);
+	void useLaserPointer(const QMouseEvent *inEvent);
+	void useDraggableTool(PDFDraggableTool* tool, const QMouseEvent *inEvent);
 	void goToDestination(const Poppler::LinkDestination &dest);
 	void doLink(const QSharedPointer<Poppler::Link> link);
 	void annotationClicked(QSharedPointer<Poppler::Annotation> annotation, int page);
@@ -305,6 +329,7 @@ private:
 	int	imagePage;
 
 	PDFMagnifier	*magnifier;
+	PDFLaserPointer	*laserPointer;
 #ifdef PHONON
 	PDFMovie	*movie;
 #endif
@@ -312,7 +337,7 @@ private:
 	int		usingTool;	// the tool actually being used in an ongoing mouse drag
 	bool		singlePageStep;
 
-	int gridx, gridy;
+	int gridx, gridy, pageOffset;
 
 	bool forceUpdate;
 
@@ -323,6 +348,7 @@ private:
 	static QCursor	*magnifierCursor;
 	static QCursor	*zoomInCursor;
 	static QCursor	*zoomOutCursor;
+	static QCursor	*focusedHandCursor;
 
 	mutable QSizeF maxPageSize; //cache pageSize
 	mutable QRectF horizontalTextRange;
@@ -387,7 +413,6 @@ public:
 	void showScale(qreal scale);
 	Q_INVOKABLE void showPage(int page);
 	Q_INVOKABLE void setResolution(int res);
-	void resetMagnifier();
 	Q_INVOKABLE void goToDestination(const QString &destName);
 	Q_INVOKABLE void goToPage(const int page);
 	Q_INVOKABLE void focus();
@@ -615,6 +640,7 @@ private:
     QAction *actionFit_to_Text_Width;
     QAction *actionGrayscale;
     QAction *actionSplitMerge;
+    QActionGroup *actionGroupGrid;
 
     QStatusBar *statusbar;
     QToolBar *toolBar;
