@@ -2,6 +2,7 @@
 #define Header_PDF_Document_Config
 
 #include <QByteArray>
+#include <QString>
 struct PDFDocumentConfig {
 	bool autoHideToolbars;
 	int windowLeft, windowTop;
@@ -28,6 +29,9 @@ struct PDFDocumentConfig {
     MagnifierShape magnifierShape;
 	bool magnifierBorder;
 
+	int laserPointerSize;
+	QString laserPointerColor; // hex rgb
+
 	QString syncFileMask;
 	QString paperColor; // hex rgb
 	QString highlightColor; // hex rgba, e.g. #FFFF003F
@@ -39,7 +43,7 @@ struct PDFDocumentConfig {
 	bool followFromCursor, followFromScroll, syncViews;
 	bool invertColors;
 	bool grayscale;
-	int gridx, gridy;
+	int gridx, gridy, pageOffset;
 };
 
 #endif // PDFDOCUMENT_CONFIG_H
