@@ -410,73 +410,6 @@ QString trimRight(const QString &s)
 		if (s[j] != ' ' && s[j] != '\t' && s[j] != '\r' && s[j] != '\n') break;
 	return s.left(j + 1);
 }
-/*!
- * \brief get argument after command 'token'
- *
- * handles latex comments correctly
- * \warning obsolete with lexer based token system
- * \param line text of one line
- * \param token latexcommand
- * \return text after token
- */
-QString findToken(const QString &line, const QString &token)
-{
-	int tagStart = line.indexOf(token);
-    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
-	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
-		tagStart += token.length();
-		int tagEnd = line.indexOf("}", tagStart);
-		if (tagEnd != -1) return line.mid(tagStart, tagEnd - tagStart);
-		else return line.mid(tagStart); //return everything after line if there is no }
-	}
-	return "";
-}
-/*!
- * \brief get argument after command 'token'
- *
- * handles latex comments correctly
- * \warning obsolete with lexer based token system
- * \param line text of one line
- * \param token latexcommand
- * \param start column number
- * \return text after token
- */
-QString findToken(const QString &line, const QString &token, int &start)
-{
-	int tagStart = line.indexOf(token, start);
-    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
-	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
-		tagStart += token.length();
-		int tagEnd = line.indexOf("}", tagStart);
-		start = tagStart;
-		if (tagEnd != -1) return line.mid(tagStart, tagEnd - tagStart);
-		else return line.mid(tagStart); //return everything after line if there is no }
-	}
-	start = -2;
-	return "";
-}
-/*!
- * \brief get argument after command 'token'
- *
- * handles latex comments correctly
- * \warning obsolete with lexer based token system
- * \param line text of one line
- * \param token regexp to search
- * \return text after token
- */
-QString findToken(const QString &line, QRegExp &token)
-{
-	//ATTENTION: token is not const because, you can't call cap on const qregexp in qt < 4.5
-	int tagStart = 0;
-	QString s = line;
-	tagStart = token.indexIn(line);
-    int commentStart = line.indexOf(QRegularExpression("(^|[^\\\\])%")); // find start of comment (if any)
-	if (tagStart != -1 && (commentStart > tagStart || commentStart == -1)) {
-		s = s.mid(tagStart + token.cap(0).length(), s.length());
-		return s;
-	}
-	return "";
-}
 
 bool findTokenWithArg(const QString &line, const QString &token, QString &outName, QString &outArg)
 {
@@ -607,26 +540,6 @@ QString getParamItem(const QString &line, int pos, bool stopAtWhiteSpace)
 	return line.mid(start, end - start);
 }
 
-QRegExp generateRegExp(const QString &text, const bool isCase, const bool isWord, const bool isRegExp)
-{
-	Qt::CaseSensitivity cs = isCase ? Qt::CaseSensitive : Qt::CaseInsensitive;
-	QRegExp m_regexp;
-	if ( isRegExp ) {
-		m_regexp = QRegExp(text, cs, QRegExp::RegExp);
-	} else if ( isWord ) {
-		//todo: screw this? it prevents searching of "world!" and similar things
-		//(qtextdocument just checks the surrounding character when searching for whole words, this would also allow wholewords|regexp search)
-		m_regexp = QRegExp(
-		               QString("\\b%1\\b").arg(QRegExp::escape(text)),
-		               cs,
-		               QRegExp::RegExp
-		           );
-	} else {
-		m_regexp = QRegExp(text, cs, QRegExp::FixedString);
-	}
-	return m_regexp;
-}
-
 QRegularExpression generateRegularExpression(const QString &text, const bool isCase, const bool isWord, const bool isRegExp)
 {
     QRegularExpression::PatternOption po = isCase ? QRegularExpression::NoPatternOption : QRegularExpression::CaseInsensitiveOption;
@@ -646,18 +559,6 @@ QRegularExpression generateRegularExpression(const QString &text, const bool isC
     return m_regexp;
 }
 
-QStringList regExpFindAllMatches(const QString &searchIn, const QRegExp &regexp, int cap)
-{
-	int offset = regexp.indexIn(searchIn);
-	QStringList res;
-	while (offset > -1) {
-		res << regexp.cap(cap);
-		offset = regexp.indexIn(searchIn, offset + regexp.matchedLength());
-	}
-	return res;
-}
-
-
 QStringList regularExpressionFindAllMatches(const QString &searchIn, const QRegularExpression &regexp, int cap)
 {
     QRegularExpressionMatch match = regexp.match(searchIn);
