@@ -48,6 +48,7 @@ void SyntaxCheck::setErrFormat(int errFormat)
 void SyntaxCheck::putLine(QDocumentLineHandle *dlh, StackEnvironment previous, TokenStack stack, bool clearOverlay, int hint)
 {
 	REQUIRE(dlh);
+    if(previous.isEmpty()) return; // sanity check as activeEnv at least contains "normal"
 	SyntaxLine newLine;
 	dlh->ref(); // impede deletion of handle while in syntax check queue
 	dlh->lockForRead();
@@ -573,7 +574,10 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 env.level = tk.level;
                 env.startingColumn=tk.start+1;
                 env.endingColumn=tk.start+tk.length-1;
-                activeEnv.push(env);
+                // avoid stacking same env (e.g. braces in braces, see #2411 )
+                Environment topEnv=activeEnv.top();
+                if(topEnv.name!=env.name)
+                    activeEnv.push(env);
             }
             newRanges.append(elem);
         }
@@ -626,7 +630,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                     tkLength--; // don't take point into misspelled word
                 }
                 Error elem;
-                elem.range = QPair<int, int>(tk.start, tk.length);
+                elem.range = QPair<int, int>(tk.start, tkLength);
                 elem.type = ERR_spelling;
                 newRanges.append(elem);
             }
