@@ -18,7 +18,7 @@ public:
 	static QString lastCheckAsString();
 	QString latestVersion() { return latestStableVersion.versionNumber; }  // returns the version number retrieved in last check(), empty if no check has been performed so far
 	void autoCheck();
-	void check(bool m_silent = true);
+	void check(bool m_silent = true, int currentComboBoxUpdateLevel = -1);
 
 signals:
 	void checkCompleted();
